summaryrefslogtreecommitdiff
path: root/include/driver/retimer/bb_retimer_public.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/driver/retimer/bb_retimer_public.h')
-rw-r--r--include/driver/retimer/bb_retimer_public.h9
1 files changed, 6 insertions, 3 deletions
diff --git a/include/driver/retimer/bb_retimer_public.h b/include/driver/retimer/bb_retimer_public.h
index f1a924f67e..d79b051504 100644
--- a/include/driver/retimer/bb_retimer_public.h
+++ b/include/driver/retimer/bb_retimer_public.h
@@ -48,9 +48,12 @@ __override_proto int bb_retimer_power_enable(const struct usb_mux *me,
*
* Set the HPD related fields in the BB retimer
*
* @param me Pointer to USB mux
* @param mux_state USB mux state containing HPD level and IRQ
*/
-void bb_retimer_hpd_update(const struct usb_mux *me, mux_state_t mux_state);
+void bb_retimer_hpd_update(const struct usb_mux *me, mux_state_t mux_state,
+ bool *ack_required);
#endif /* __CROS_EC_DRIVER_RETIMER_BB_RETIMER_PUBLIC_H */
@@ -48,9 +48,12 @@ __override_proto int bb_retimer_power_enable(const struct usb_mux *me,
* Set the HPD related fields in the BB retimer
*
- * @param me Pointer to USB mux
- * @param mux_state USB mux state containing HPD level and IRQ
+ * @param[in] me Pointer to USB mux
+ * @param[in] mux_state USB mux state containing HPD level and IRQ
+ * @param[out] ack_required Outputs whether the given change will require
+ * the AP to ACK before proceeding
*/